@@ -1,7 +1,8 @@
 package Test::Magpie::Util;
 BEGIN {
-  $Test::Magpie::Util::VERSION = '0.01_01';
+  $Test::Magpie::Util::VERSION = '0.01';
 }
+# ABSTRACT: Utilities used by Test::Magpie
 use strict;
 use warnings;
 
@@ -17,6 +18,8 @@ sub extract_method_name {
 
 1;
 
+
+
 __END__
 =pod
 
@@ -24,11 +27,18 @@ __END__
 
 =head1 NAME
 
-Test::Magpie::Util
+Test::Magpie::Util - Utilities used by Test::Magpie
+
+=head1 METHODS
+
+=head2 extract_method_name
+
+Internal. From a fully qualified method name such as Foo::Bar::baz, will return
+just the method name (in this example, baz).
 
 =head1 AUTHOR
 
-  Oliver Charles
+Oliver Charles
 
 =head1 COPYRIGHT AND LICENSE
 
