@@ -1,7 +1,8 @@
 package Test::Magpie::When;
 BEGIN {
-  $Test::Magpie::When::VERSION = '0.01_01';
+  $Test::Magpie::When::VERSION = '0.01';
 }
+# ABSTRACT: The process of stubbing a mock method call
 use Moose;
 use namespace::autoclean;
 
@@ -23,12 +24,19 @@ sub AUTOLOAD {
         arguments => \@_
     );
 
-    add_stub($mock, $stub);
+    my $stubs = find_meta($mock)->find_attribute_by_name('stubs')
+        ->get_value($mock);
+
+    my $method = $stub->method_name;
+    $stubs->{$method} ||= [];
+    push @{ $stubs->{$method} }, $stub;
+
     return $stub;
 }
 
 1;
 
+
 __END__
 =pod
 
@@ -36,11 +44,20 @@ __END__
 
 =head1 NAME
 
-Test::Magpie::When
+Test::Magpie::When - The process of stubbing a mock method call
+
+=head1 DESCRIPTION
+
+A mock object in stub mode to declare a stubbed method. You generate this by
+calling C<when> in L<Test::Magpie> with a mock object.
+
+This object has the same API as the mock object - any method call will start the
+creation of a L<Test::Magpie::Stub>, which can be modified to tailor the stub
+call. You are probably more interested in that documentation.
 
 =head1 AUTHOR
 
-  Oliver Charles
+Oliver Charles
 
 =head1 COPYRIGHT AND LICENSE
 
